.. highlight:: shell

====
API
===


Main
=====================
.. automodule:: retail_sales_prediction.main
   :members:

Data Loaders
=====================
.. automodule:: retail_sales_prediction.utils.data_loader
   :members:

Data Preparation
=====================
.. automodule:: retail_sales_prediction.utils.data_preparation
   :members:

Model Collection
=====================
.. automodule:: retail_sales_prediction.utils.run_model
   :members:
